# AI Agent Modeling Guidelines
### On this page
  * [Definition](https://help.sap.com/docs/leanix/ea/ai-agent-modeling-guidelines#definition)
  * [Description](https://help.sap.com/docs/leanix/ea/ai-agent-modeling-guidelines#description)
  * [Modeling Guidelines](https://help.sap.com/docs/leanix/ea/ai-agent-modeling-guidelines#modeling-guidelines)
  * [Best Practices](https://help.sap.com/docs/leanix/ea/ai-agent-modeling-guidelines#best-practices)
  * [Antipatterns](https://help.sap.com/docs/leanix/ea/ai-agent-modeling-guidelines#antipatterns)
  * [Related Information](https://help.sap.com/docs/leanix/ea/ai-agent-modeling-guidelines#related-information)


Explore best practices for modeling AI agents and learn how to avoid common antipatterns.
